@@ -77,9 +77,12 @@ def get_file_extension(file):
 
     return extension
 
+
 def execute_pgsql_query(sql, host=None, port=None, user=None, password=None, dbname=None, secrets_manager_key=None):
     """executes a psql query"""
-    logger.debug(f"execute_pgsql_query('{sql}','{host}','{port}','{user}','password','{dbname}',''{secrets_manager_key}) called")
+    logger.debug(
+        f"execute_pgsql_query('{sql}','{host}','{port}','{user}','password','{dbname}',''{secrets_manager_key}) called"
+    )
 
     if secrets_manager_key:
         secret = json.loads(awsUtils.secrets_manager_get_secret(secrets_manager_key))
@@ -93,7 +96,7 @@ def execute_pgsql_query(sql, host=None, port=None, user=None, password=None, dbn
         logger.debug(f"user: {user}")
         password = secret["password"]
 
-    conn =  psycopg2.connect(dbname=dbname, user=user, password=password, host=host, port=port)
+    conn = psycopg2.connect(dbname=dbname, user=user, password=password, host=host, port=port)
     cur = conn.cursor()
     try:
         cur.execute(sql)
@@ -101,11 +104,10 @@ def execute_pgsql_query(sql, host=None, port=None, user=None, password=None, dbn
         return str(e)
     else:
         conn.commit()
-        # fetch the column names
-        columns = [desc[0] for desc in cur.description]
-        results = [dict(zip(columns, row)) for row in cur.fetchall()]
-
-        return results
+        if cur.fetchall() != None:
+            columns = [desc[0] for desc in cur.description]
+            results = [dict(zip(columns, row)) for row in cur.fetchall()]
+            return results
     finally:
         cur.close()
         conn.close()
